@@ -29,6 +29,7 @@
 #include <gtk/gtk.h>
 
 #ifdef HAVE_CLUTTER
+#include <cogl/cogl.h>
 #include <clutter/clutter.h>
 #include <clutter-gtk/clutter-gtk.h>
 #endif
@@ -59,6 +60,13 @@
 #include "game.h"
 #include "window.h"
 
+#if 0
+/* String reserve */
+N_("Solitaire")
+N_("GNOME Solitaire")
+N_("About Solitaire")
+#endif /* 0 */
+
 typedef struct {
   AisleriotWindow *window;
   char *variation;
@@ -283,6 +291,7 @@ main_prog (void *closure, int argc, char *argv[])
   g_option_context_add_group (option_context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
 #ifdef HAVE_CLUTTER
+  g_option_context_add_group (option_context, cogl_get_option_group ());
   g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
 #endif
 
