@@ -1,25 +1,24 @@
 /*
- *  Copyright © 2007 Christian Persch
+ * Copyright © 2007 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope window it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef AISLERIOT_WINDOW_H
 #define AISLERIOT_WINDOW_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 #ifdef HAVE_HILDON
 #ifdef HAVE_MAEMO_3
@@ -62,9 +61,7 @@ typedef GtkWindowClass AisleriotWindowClass;
 
 GType aisleriot_window_get_type (void);
 
-GtkWidget *aisleriot_window_new (void);
-
-void aisleriot_window_set_freecell_mode (AisleriotWindow * window);
+GtkWidget *aisleriot_window_new (gboolean freecell_mode);
 
 void aisleriot_window_set_game (AisleriotWindow * window,
                                 const char *game_file, guint seed);
