@@ -1,9 +1,10 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
-/* 
+/*
  *   Gnome Nibbles: Gnome Worm Game
- *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
- * 
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>,
+ *              Guillaume Beland <guillaume.beland@gmail.com>
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -39,13 +40,18 @@
 #include "main.h"
 #include "properties.h"
 #include "gnibbles.h"
-#include "worm.h"
 #include "bonus.h"
 #include "boni.h"
 #include "preferences.h"
 #include "scoreboard.h"
 #include "warp.h"
 
+#include <clutter-gtk/clutter-gtk.h>
+#include <clutter/clutter.h>
+
+#include "board.h"
+#include "worm.h"
+
 #ifdef GGZ_CLIENT
 #include <libgames-support/games-dlg-chat.h>
 #include <libgames-support/games-dlg-players.h>
@@ -57,7 +63,6 @@
 #define DEFAULT_HEIGHT 520
 
 GtkWidget *window;
-GtkWidget *drawing_area;
 GtkWidget *statusbar;
 GtkWidget *notebook;
 GtkWidget *chat = NULL;
@@ -80,16 +85,19 @@ extern GdkPixbuf *logo_pixmap;
 
 GnibblesProperties *properties;
 
+GnibblesBoard *board;
+
 GnibblesScoreboard *scoreboard;
 
-extern GnibblesBoni *boni;
+GtkWidget *clutter_widget;
+ClutterActor *stage;
 
-gchar board[BOARDWIDTH][BOARDHEIGHT];
+extern GnibblesWorm *worms[];
+extern GnibblesBoni *boni;
 
 gint main_id = 0;
 gint dummy_id = 0;
 gint keyboard_id = 0;
-gint erase_id = 0;
 gint add_bonus_id = 0;
 gint restart_id = 0;
 
@@ -97,15 +105,11 @@ gint paused = 0;
 
 gint current_level;
 
-static struct _pointers {
-  GdkCursor *current;
-  GdkCursor *invisible;
-} pointers = {
-NULL};
-
 static gint add_bonus_cb (gpointer data);
+
 static void render_logo (void);
 static gint end_game_cb (GtkAction * action, gpointer data);
+static void hide_logo (void);
 
 static GtkAction *new_game_action;
 static GtkAction *new_network_action;
@@ -118,13 +122,12 @@ static GtkAction *scores_action;
 static GtkAction *fullscreen_action;
 static GtkAction *leave_fullscreen_action;
 
+static ClutterActor *logo;
+
 static void
 hide_cursor (void)
 {
-  if (pointers.current != pointers.invisible) {
-    gdk_window_set_cursor (drawing_area->window, pointers.invisible);
-    pointers.current = pointers.invisible;
-  }
+  clutter_stage_hide_cursor (CLUTTER_STAGE (stage));
 }
 
 static void
@@ -146,6 +149,7 @@ fullscreen_cb (GtkAction * action)
     gtk_window_unfullscreen (GTK_WINDOW (window));
   }
 }
+
 static void
 network_gui_update (void)
 {
@@ -169,8 +173,8 @@ window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
   /* Handle fullscreen, in case something else takes us to/from fullscreen. */
   if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
     set_fullscreen_actions (event->new_window_state
-			    & GDK_WINDOW_STATE_FULLSCREEN);
-    
+                            & GDK_WINDOW_STATE_FULLSCREEN);
+
   return FALSE;
 }
 
@@ -178,28 +182,13 @@ window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
 static void
 show_cursor (void)
 {
-  if (pointers.current != NULL) {
-    gdk_window_set_cursor (drawing_area->window, NULL);
-    pointers.current = NULL;
-  }
+  clutter_stage_show_cursor (CLUTTER_STAGE (stage));
 }
 
 gint
 game_running (void)
 {
-  return (main_id || erase_id || dummy_id || restart_id || paused);
-}
-
-static void
-zero_board (void)
-{
-  gint i, j;
-
-  for (i = 0; i < BOARDWIDTH; i++)
-    for (j = 0; j < BOARDHEIGHT; j++) {
-      board[i][j] = EMPTYCHAR;
-      gnibbles_draw_pixmap_buffer (0, i, j);
-    }
+  return (main_id || dummy_id || restart_id || paused);
 }
 
 static void
@@ -218,8 +207,6 @@ delete_cb (GtkWidget * widget, gpointer data)
 {
   if (main_id)
     g_source_remove (main_id);
-  if (erase_id)
-    g_source_remove (erase_id);
   if (dummy_id)
     g_source_remove (dummy_id);
   if (restart_id)
@@ -237,90 +224,50 @@ quit_cb (GObject * object, gpointer data)
 static void
 about_cb (GtkAction * action, gpointer data)
 {
-  const gchar *authors[] = { "Sean MacIsaac", "Ian Peters", "Andreas Røsdal", NULL };
+  const gchar *authors[] = { "Sean MacIsaac", "Ian Peters", "Andreas Røsdal",
+                             "Guillaume Beland", NULL };
 
   const gchar *documenters[] = { "Kevin Breit", NULL };
   gchar *license = games_get_license (_("Nibbles"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
 #if GTK_CHECK_VERSION (2, 11, 0)
-                         "program-name", _("Nibbles"),
+       "program-name", _("Nibbles"),
 #else
-			 "name", _("Nibbles"),
+       "name", _("Nibbles"),
 #endif
-			 "version", VERSION,
-			 "copyright",
-			 "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal",
-			 "license", license, "comments",
-			 _("A worm game for GNOME.\n\nNibbles is a part of GNOME Games."), "authors", authors,
-			 "documenters", documenters, "translator-credits",
-			 _("translator-credits"), "logo-icon-name",
-			 "gnome-gnibbles", "website",
-			 "http://www.gnome.org/projects/gnome-games/",
-			 "website-label", _("GNOME Games web site"),
-			 "wrap-license", TRUE, NULL);
+       "version", VERSION,
+       "copyright",
+       "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal"
+       "2009 Guillaume Beland",
+       "license", license, "comments",
+       _("A worm game for GNOME.\n\nNibbles is a part of GNOME Games."),
+       "authors", authors,
+       "documenters", documenters, "translator-credits",
+       _("translator-credits"), "logo-icon-name",
+       "gnome-gnibbles", "website",
+       "http://www.gnome.org/projects/gnome-games/",
+       "website-label", _("GNOME Games web site"),
+       "wrap-license", TRUE, NULL);
   g_free (license);
 }
 
-static gint
-expose_event_cb (GtkWidget * widget, GdkEventExpose * event)
-{
-  gdk_draw_drawable (GDK_DRAWABLE (widget->window),
-		     widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-		     buffer_pixmap, event->area.x, event->area.y,
-		     event->area.x, event->area.y, event->area.width,
-		     event->area.height);
-
-  return (FALSE);
-}
-
-static gint
-key_press_cb (GtkWidget * widget, GdkEventKey * event)
+static gboolean
+key_press_cb (ClutterActor *actor, ClutterEvent *event, gpointer data)
 {
   hide_cursor ();
 
-  return gnibbles_keypress_worms (event->keyval);
-}
-
-static void
-draw_board (void)
-{
-  int i, j;
-
-  for (i = 0; i < BOARDWIDTH; i++) {
-    for (j = 0; j < BOARDHEIGHT; j++) {
-      gnibbles_draw_pixmap_buffer (0, i, j);
-      if (board[i][j] >= EMPTYCHAR && board[i][j] < EMPTYCHAR + 19) {
-	gnibbles_draw_pixmap_buffer (board[i][j] - EMPTYCHAR, i, j);
-      } else if (board[i][j] >= WORMCHAR && board[i][j] < WORMCHAR + NUMWORMS) {
-	gnibbles_draw_pixmap_buffer (properties->wormprops
-				     [board[i][j] - WORMCHAR]->color, i, j);
-      } else if (board[i][j] >= 'A' && board[i][j] < 'J') {
-	/* bonus */
-      } else {
-	/* Warp point. */
-      }
-    }
-  }
-
-  for (i = 0; i < boni->numbonuses; i++)
-    gnibbles_bonus_draw (boni->bonuses[i]);
-
-  for (i = 0; i < warpmanager->numwarps; i++)
-    gnibbles_warp_draw_buffer (warpmanager->warps[i]);
-
-  gdk_draw_drawable (GDK_DRAWABLE (drawing_area->window),
-		     drawing_area->style->
-		     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 0,
-		     0, 0, 0, BOARDWIDTH * properties->tilesize,
-		     BOARDHEIGHT * properties->tilesize);
+  if (!(event->type == CLUTTER_KEY_PRESS))
+    return FALSE;
 
+  return gnibbles_keypress_worms (event->key.keyval);
 }
 
 static gboolean
-configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
+configure_event_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 {
   int tilesize, ts_x, ts_y;
+  int i;
 
   /* Compute the new tile size based on the size of the
    * drawing area, rounded down. */
@@ -332,71 +279,74 @@ configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
     ts_y--;
   tilesize = MIN (ts_x, ts_y);
 
+  gnibbles_load_pixmap (tilesize);
+  gnibbles_load_logo (tilesize);
+
+  clutter_actor_set_size (CLUTTER_ACTOR (stage),
+                          BOARDWIDTH * tilesize,
+                          BOARDWIDTH * tilesize);
+  if (game_running ()) {
+    if (board) {
+      gnibbles_board_rescale (board, tilesize);
+      gnibbles_boni_rescale (boni, tilesize);
+
+      for (i=0; i<properties->numworms; i++)
+        gnibbles_worm_rescale (worms[i], tilesize);
+
+      if (warpmanager)
+        gnibbles_warpmanager_rescale (warpmanager, tilesize);
+    }
+  } else {
+    if (logo)
+      hide_logo ();
+
+    if (board)
+      gnibbles_board_rescale (board, tilesize);
+
+    render_logo ();
+  }
+
   /* But, has the tile size changed? */
   if (properties->tilesize == tilesize) {
-
     /* We must always re-load the logo. */
-    gnibbles_load_logo (window);
+    gnibbles_load_logo (tilesize);
     return FALSE;
   }
 
   properties->tilesize = tilesize;
   gnibbles_properties_set_tile_size (tilesize);
 
-  /* Reload the images pixmap. */
-  gnibbles_load_logo (window);
-  gnibbles_load_pixmap (window);
-
-  /* Recreate the buffer pixmap. */
-  if (buffer_pixmap)
-    g_object_unref (G_OBJECT (buffer_pixmap));
-  buffer_pixmap = gdk_pixmap_new (drawing_area->window,
-				  BOARDWIDTH * properties->tilesize,
-				  BOARDHEIGHT * properties->tilesize, -1);
-
-  /* Erase the buffer pixmap. */
-  gdk_draw_rectangle (buffer_pixmap,
-		      drawing_area->style->black_gc,
-		      TRUE, 0, 0,
-		      BOARDWIDTH * properties->tilesize,
-		      BOARDHEIGHT * properties->tilesize);
-
-  if (game_running ())
-    draw_board ();
-  else
-    render_logo ();
-
   return FALSE;
 }
 
 #ifdef GGZ_CLIENT
-static gint
+static gboolean
 network_loop (gpointer data)
 {
-  if (ggz_network_mode) { 
+  if (ggz_network_mode) {
     network_move_worms ();
   }
   return TRUE;
 }
 #endif
 
-static gint
+static gboolean
 new_game_2_cb (GtkWidget * widget, gpointer data)
 {
   if (!paused) {
     if (!keyboard_id)
-      keyboard_id = g_signal_connect (G_OBJECT (window),
-				      "key_press_event",
-				      G_CALLBACK (key_press_cb), NULL);
+      keyboard_id = g_signal_connect (G_OBJECT (stage),
+                                      "key-press-event",
+                                      G_CALLBACK (key_press_cb), NULL);
 #ifdef GGZ_CLIENT
     if (!main_id && ggz_network_mode && network_is_host ()) {
       main_id = g_timeout_add (GAMEDELAY * (properties->gamespeed + NETDELAY),
-			       (GSourceFunc) network_loop, NULL);
+                               (GSourceFunc) network_loop, NULL);
     } else
 #endif
     if (!main_id && !ggz_network_mode) {
       main_id = g_timeout_add (GAMEDELAY * properties->gamespeed,
-			       (GSourceFunc) main_loop, NULL);
+                               (GSourceFunc) main_loop, NULL);
     }
 #ifdef GGZ_CLIENT
     if (!add_bonus_id && network_is_host ()) {
@@ -404,19 +354,21 @@ new_game_2_cb (GtkWidget * widget, gpointer data)
     if (!add_bonus_id) {
 #endif
       add_bonus_id = g_timeout_add (BONUSDELAY *
-				    properties->gamespeed,
-				    (GSourceFunc) add_bonus_cb, NULL);
+                                    properties->gamespeed,
+                                    (GSourceFunc) add_bonus_cb, NULL);
     }
   }
 
   dummy_id = 0;
 
-  return (FALSE);
+  return FALSE;
 }
 
-gint
+gboolean
 new_game (void)
 {
+  int i;
+
   gtk_action_set_sensitive (new_network_action, FALSE);
 
   if (ggz_network_mode) {
@@ -432,29 +384,28 @@ new_game (void)
     main_id = 0;
   }
 
-  gnibbles_init ();
-
   if (ggz_network_mode || !properties->random) {
     current_level = properties->startlevel;
   } else {
     current_level = rand () % MAXLEVEL + 1;
   }
 
-  zero_board ();
-  gnibbles_load_level (GTK_WIDGET (window), current_level);
+  hide_logo ();
+  gnibbles_init ();
+  gnibbles_board_level_new (board, current_level);
+  gnibbles_board_level_add_bonus (board, 1);
 
-  gnibbles_add_bonus (1);
+  for (i = 0; i < properties->numworms; i++) {
+    if (!clutter_actor_get_stage (worms[i]->actors))
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), worms[i]->actors);
+    gnibbles_worm_show (worms[i]);
+  }
 
   paused = 0;
   gtk_action_set_visible (pause_action, !paused);
   gtk_action_set_visible (resume_action, paused);
   gtk_action_set_visible (player_list_action, ggz_network_mode);
 
-  if (erase_id) {
-    g_source_remove (erase_id);
-    erase_id = 0;
-  }
-
   if (restart_id) {
     g_source_remove (restart_id);
     restart_id = 0;
@@ -481,30 +432,30 @@ new_game_cb (GtkAction * action, gpointer data)
   new_game ();
 }
 
-
-gint
+gboolean
 pause_game_cb (GtkAction * action, gpointer data)
 {
   if (paused) {
     paused = 0;
     dummy_id = g_timeout_add (500, (GSourceFunc) new_game_2_cb, NULL);
   } else {
-    if (main_id || erase_id || restart_id || dummy_id) {
+    if (main_id || restart_id || dummy_id) {
       paused = 1;
       if (main_id) {
-	g_source_remove (main_id);
-	main_id = 0;
+        g_source_remove (main_id);
+        main_id = 0;
       }
       if (keyboard_id) {
-	g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
-	keyboard_id = 0;
+        g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
+        keyboard_id = 0;
       }
       if (add_bonus_id) {
-	g_source_remove (add_bonus_id);
-	add_bonus_id = 0;
+        g_source_remove (add_bonus_id);
+        add_bonus_id = 0;
       }
     }
   }
+
   gtk_action_set_sensitive (pause_action, !paused);
   gtk_action_set_sensitive (resume_action, paused);
   gtk_action_set_visible (pause_action, !paused);
@@ -528,7 +479,7 @@ end_game (gboolean show_splash)
   }
 
   if (keyboard_id) {
-    g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
+    g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
     keyboard_id = 0;
   }
 
@@ -537,11 +488,6 @@ end_game (gboolean show_splash)
     add_bonus_id = 0;
   }
 
-  if (erase_id) {
-    g_source_remove (erase_id);
-    erase_id = 0;
-  }
-
   if (dummy_id) {
     g_source_remove (dummy_id);
     dummy_id = 0;
@@ -566,7 +512,7 @@ end_game (gboolean show_splash)
 
 }
 
-static gint
+static gboolean
 end_game_cb (GtkAction * action, gpointer data)
 {
 
@@ -578,52 +524,81 @@ end_game_cb (GtkAction * action, gpointer data)
 #endif
 
   end_game (TRUE);
-  return (FALSE);
+  return FALSE;
 }
 
-static gint
+static gboolean
 add_bonus_cb (gpointer data)
 {
-  gnibbles_add_bonus (0);
-
-  return (TRUE);
+  gnibbles_board_level_add_bonus (board, 0);
+  return TRUE;
 }
 
-static gint
+static gboolean
 restart_game (gpointer data)
 {
-  zero_board ();
-  gnibbles_load_level (GTK_WIDGET (window), current_level);
+  int i;
 
-  gnibbles_add_bonus (1);
+  gnibbles_board_level_new (board, current_level);
+  gnibbles_board_level_add_bonus (board, 1);
 
-  dummy_id = g_timeout_add_seconds (1, (GSourceFunc) new_game_2_cb, NULL);
-
-  restart_id = 0;
-
-  return (FALSE);
-}
-
-static gint
-erase_worms_cb (gpointer datap)
-{
-  gint data = GPOINTER_TO_INT (datap);
-
-  if (data == 0) {
-    erase_id = 0;
-    if (!restart_id)
-      end_game (TRUE);
-  } else {
-    gnibbles_undraw_worms (ERASESIZE - data);
-    erase_id = g_timeout_add (ERASETIME / ERASESIZE,
-			      (GSourceFunc) erase_worms_cb,
-			      GINT_TO_POINTER (data - 1));
+  for (i = 0; i < properties->numworms; i++) {
+    if (!clutter_actor_get_stage (worms[i]->actors))
+      clutter_container_add_actor (CLUTTER_CONTAINER (stage), worms[i]->actors);
+    gnibbles_worm_show (worms[i]);
   }
 
-  return (FALSE);
+  for (i = 0; i < properties->human; i++)
+    worms[i]->human = TRUE;
+
+  dummy_id = g_timeout_add_seconds (1, (GSourceFunc) new_game_2_cb, NULL);
+  restart_id = 0;
+
+  return FALSE;
 }
 
-gint
+static void
+end_game_anim_cb (ClutterAnimation *animation, ClutterActor *actor)
+{
+  if (!restart_id)
+    end_game (TRUE);
+}
+
+static void
+animate_end_game (void)
+{
+  int i;
+  for (i = 0; i < properties->numworms; i++) {
+    clutter_actor_animate (worms[i]->actors, CLUTTER_EASE_IN_QUAD, 500,
+                           "opacity", 0,
+                           "scale-x", 0.4, "scale-y", 0.4,
+                           "fixed::scale-center-x",
+                           (gfloat) worms[i]->xhead * properties->tilesize,
+                           "fixed::scale-center-y",
+                           (gfloat) worms[i]->yhead * properties->tilesize,
+                           NULL);
+  }
+
+  for ( i = 0; i < boni->numbonuses; i++) {
+    clutter_actor_animate (boni->bonuses[i]->actor, CLUTTER_EASE_IN_QUAD, 500,
+                           "opacity", 0,
+                           "scale-x", 0.4, "scale-y", 0.4,
+                           "fixed::scale-gravity", CLUTTER_GRAVITY_CENTER,
+                           NULL);
+
+  }
+
+  g_signal_connect_after (
+    clutter_actor_animate (board->level, CLUTTER_EASE_IN_QUAD, 700,
+                           "scale-x", 0.4, "scale-y", 0.4,
+                           "fixed::scale-gravity", CLUTTER_GRAVITY_CENTER,
+                           "opacity", 0,
+                           NULL),
+    "completed", G_CALLBACK (end_game_anim_cb), NULL);
+
+}
+
+gboolean
 main_loop (gpointer data)
 {
   gint status;
@@ -636,54 +611,52 @@ main_loop (gpointer data)
   if (status == VICTORY) {
     end_game (TRUE);
     winner = gnibbles_get_winner ();
+
     if (winner == -1)
       return FALSE;
 
     str = g_strdup_printf (_("Game over! The game has been won by %s!"),
-			   names[winner]);
+                             names[winner]);
 #ifdef GGZ_CLIENT
     add_chat_text (str);
 #endif
     g_free (str);
 
     if (keyboard_id) {
-      g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
+      g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
       keyboard_id = 0;
     }
     if (main_id) {
       g_source_remove (main_id);
       main_id = 0;
     }
-    if (add_bonus_id) {
+    if (add_bonus_id)
       g_source_remove (add_bonus_id);
-    }
+
     add_bonus_id = 0;
-    erase_id = g_timeout_add_seconds (3,
-			      (GSourceFunc) erase_worms_cb,
-			      (gpointer) ERASESIZE);
+
+    animate_end_game ();
     gnibbles_log_score (window);
 
     return FALSE;
-
-
   }
 
   if (status == GAMEOVER) {
 
     if (keyboard_id) {
-      g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
+      g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
       keyboard_id = 0;
     }
     main_id = 0;
-    if (add_bonus_id) {
+    if (add_bonus_id)
       g_source_remove (add_bonus_id);
-    }
+
     add_bonus_id = 0;
-    erase_id = g_timeout_add_seconds (3,
-			      (GSourceFunc) erase_worms_cb,
-			      (gpointer) ERASESIZE);
+
+    animate_end_game ();
     gnibbles_log_score (window);
-    return (FALSE);
+
+    return FALSE;
   }
 
   if (status == NEWROUND) {
@@ -696,58 +669,60 @@ main_loop (gpointer data)
 #endif
 
     if (keyboard_id) {
-      g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
+      g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
       keyboard_id = 0;
     }
-    if (add_bonus_id) {
+    if (add_bonus_id)
       g_source_remove (add_bonus_id);
-    }
+
     if (main_id) {
       g_source_remove (main_id);
       main_id = 0;
     }
     add_bonus_id = 0;
-    erase_id = g_timeout_add (ERASETIME / ERASESIZE,
-			      (GSourceFunc) erase_worms_cb,
-			      (gpointer) ERASESIZE);
+
+    animate_end_game ();
     restart_id = g_timeout_add_seconds (1, (GSourceFunc) restart_game, NULL);
-    return (FALSE);
+
+    return FALSE;
   }
 
   if (boni->numleft == 0) {
-    if (restart_id) {
+    if (restart_id)
       return TRUE;
-    }
-    if (keyboard_id) {
-      g_signal_handler_disconnect (G_OBJECT (window), keyboard_id);
-    }
+
+    if (keyboard_id)
+      g_signal_handler_disconnect (G_OBJECT (stage), keyboard_id);
+
     keyboard_id = 0;
-    if (add_bonus_id) {
+
+    if (add_bonus_id)
       g_source_remove (add_bonus_id);
-    }
+
     add_bonus_id = 0;
     if (main_id) {
       g_source_remove (main_id);
       main_id = 0;
     }
     if ((current_level < MAXLEVEL) && (!properties->random
-				       || ggz_network_mode))
+                                       || ggz_network_mode)) {
       current_level++;
-    else if (properties->random && !ggz_network_mode) {
+    } else if (properties->random && !ggz_network_mode) {
       tmp = rand () % MAXLEVEL + 1;
       while (tmp == current_level)
-	tmp = rand () % MAXLEVEL + 1;
+        tmp = rand () % MAXLEVEL + 1;
       current_level = tmp;
     }
+    animate_end_game ();
     restart_id = g_timeout_add_seconds (1, (GSourceFunc) restart_game, NULL);
-    return (FALSE);
+    return FALSE;
   }
 
-  return (TRUE);
+  return TRUE;
 }
 
 static gboolean
-show_cursor_cb (GtkWidget * widget, GdkEventMotion * event, gpointer data)
+show_cursor_cb (GtkWidget * widget, GdkEventMotion *event, gpointer data)
 {
   show_cursor ();
   return FALSE;
@@ -818,18 +793,21 @@ static const char ui_description[] =
   "    </menu>"
   "    <menu action='HelpMenu'>"
   "      <menuitem action='Contents'/>"
-  "      <menuitem action='About'/>" "    </menu>" "  </menubar>" "</ui>";
+  "      <menuitem action='About'/>"
+  "    </menu>"
+  "  </menubar>"
+  "</ui>";
 
 static void
 create_menus (GtkUIManager * ui_manager)
 {
   GtkActionGroup *action_group;
 
-  action_group = gtk_action_group_new ("group");
+  action_group = gtk_action_group_new ("MenuActions");
 
   gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
   gtk_action_group_add_actions (action_group, action_entry,
-				G_N_ELEMENTS (action_entry), window);
+                                G_N_ELEMENTS (action_entry), window);
 
   gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
   gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
@@ -839,45 +817,58 @@ create_menus (GtkUIManager * ui_manager)
   end_game_action = gtk_action_group_get_action (action_group, "EndGame");
   pause_action = gtk_action_group_get_action (action_group, "Pause");
   resume_action = gtk_action_group_get_action (action_group, "Resume");
-  preferences_action =
-    gtk_action_group_get_action (action_group, "Preferences");
-  fullscreen_action =
-    gtk_action_group_get_action (action_group, "Fullscreen");
-  leave_fullscreen_action =
-    gtk_action_group_get_action (action_group, "LeaveFullscreen");
-  new_network_action =
-    gtk_action_group_get_action (action_group, "NewNetworkGame");
+
+  preferences_action = gtk_action_group_get_action (action_group,
+                                                    "Preferences");
+  fullscreen_action = gtk_action_group_get_action (action_group,
+                                                   "Fullscreen");
+  leave_fullscreen_action = gtk_action_group_get_action (action_group,
+                                                         "LeaveFullscreen");
+  new_network_action = gtk_action_group_get_action (action_group,
+                                                    "NewNetworkGame");
 #ifndef GGZ_CLIENT
   gtk_action_set_sensitive (new_network_action, FALSE);
 #endif
-  player_list_action =
-    gtk_action_group_get_action (action_group, "PlayerList");
-
+  player_list_action = gtk_action_group_get_action (action_group, "PlayerList");
 
 }
 
 static void
 setup_window (void)
 {
-  GdkPixmap *cursor_dot_pm;
   GtkWidget *vbox;
-  GtkWidget *main_vbox;
   GtkWidget *packing;
   GtkWidget *menubar;
+
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
+  ClutterColor stage_color = {0x00,0x00,0x00,0xff};
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  clutter_widget = gtk_clutter_embed_new ();
+  stage = gtk_clutter_embed_get_stage (GTK_CLUTTER_EMBED (clutter_widget));
+
+  clutter_stage_set_color (CLUTTER_STAGE(stage), &stage_color);
+
+  clutter_actor_set_size (CLUTTER_ACTOR (stage),
+                          properties->tilesize * BOARDWIDTH,
+                          properties->tilesize * BOARDHEIGHT);
+  clutter_stage_set_user_resizable (CLUTTER_STAGE (stage), FALSE);
+
+  board = gnibbles_board_new ();
+
   gtk_window_set_title (GTK_WINDOW (window), _("Nibbles"));
 
-  gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
+  gtk_window_set_default_size (GTK_WINDOW (window),
+                               DEFAULT_WIDTH, DEFAULT_HEIGHT);
   games_conf_add_window (GTK_WINDOW (window), KEY_PREFERENCES_GROUP);
 
-  g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
+  g_signal_connect (G_OBJECT (window), "destroy",
+                    G_CALLBACK (gtk_main_quit), NULL);
   g_signal_connect (G_OBJECT (window), "delete_event",
-		    G_CALLBACK (delete_cb), NULL);
+                    G_CALLBACK (delete_cb), NULL);
   g_signal_connect (G_OBJECT (window), "window_state_event",
-		    G_CALLBACK (window_state_cb), NULL);
+                    G_CALLBACK (window_state_cb), NULL);
 
   gtk_widget_realize (window);
 
@@ -894,130 +885,171 @@ setup_window (void)
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 
   menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
+
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 
   packing = games_grid_frame_new (BOARDWIDTH, BOARDHEIGHT);
-  gtk_box_pack_start (GTK_BOX (vbox), packing, TRUE, TRUE, 0);
   gtk_widget_show (packing);
 
-  drawing_area = gtk_drawing_area_new ();
+  gtk_container_add (GTK_CONTAINER (packing), clutter_widget);
 
-  cursor_dot_pm = gdk_pixmap_create_from_data (window->window, "\0", 1, 1, 1,
-					       &drawing_area->style->
-					       fg[GTK_STATE_ACTIVE],
-					       &drawing_area->style->
-					       bg[GTK_STATE_ACTIVE]);
-
-  pointers.invisible =
-    gdk_cursor_new_from_pixmap (cursor_dot_pm, cursor_dot_pm,
-				&drawing_area->style->fg[GTK_STATE_ACTIVE],
-				&drawing_area->style->bg[GTK_STATE_ACTIVE], 0,
-				0);
-
-  gtk_container_add (GTK_CONTAINER (packing), drawing_area);
 #ifdef GGZ_CLIENT
   chat = create_chat_widget ();
   gtk_box_pack_start (GTK_BOX (vbox), chat, FALSE, TRUE, 0);
 #endif
 
-  g_signal_connect (G_OBJECT (drawing_area), "configure_event",
-		    G_CALLBACK (configure_event_cb), NULL);
-
-  g_signal_connect (G_OBJECT (drawing_area), "motion_notify_event",
-		    G_CALLBACK (show_cursor_cb), NULL);
+  g_signal_connect (G_OBJECT (clutter_widget), "configure_event",
+                    G_CALLBACK (configure_event_cb), NULL);
 
   g_signal_connect (G_OBJECT (window), "focus_out_event",
-		    G_CALLBACK (show_cursor_cb), NULL);
+                    G_CALLBACK (show_cursor_cb), NULL);
 
-  gtk_widget_set_size_request (GTK_WIDGET (drawing_area),
-			       BOARDWIDTH * 5, BOARDHEIGHT * 5);
-  g_signal_connect (G_OBJECT (drawing_area), "expose_event",
-		    G_CALLBACK (expose_event_cb), NULL);
-  /* We do our own double-buffering. */
-  gtk_widget_set_double_buffered (GTK_WIDGET (drawing_area), FALSE);
-  gtk_widget_set_events (drawing_area, GDK_BUTTON_PRESS_MASK |
-			 GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK);
-
-  main_vbox = gtk_vbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, NULL);
+  gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), packing, NULL);
   gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), MAIN_PAGE);
 
   statusbar = gtk_statusbar_new ();
-  gtk_box_pack_start (GTK_BOX (main_vbox), statusbar, FALSE, FALSE, 0);
-
-  gtk_container_add (GTK_CONTAINER (window), main_vbox);
+  gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
+  gtk_container_add (GTK_CONTAINER (window), vbox);
 
   gtk_widget_show_all (window);
 #ifdef GGZ_CLIENT
   gtk_widget_hide (chat);
 #endif
-  gtk_widget_show (drawing_area);
 
   scoreboard = gnibbles_scoreboard_new (statusbar);
-
 }
 
 static void
 render_logo (void)
 {
-  PangoContext *context;
+  ClutterActor *image;
+  ClutterActor *text, *text_shadow;
+  ClutterActor *desc, *desc_shadow;
+  ClutterColor actor_color = {0xff,0xff,0xff,0xff};
+  ClutterColor shadow_color = {0x00, 0x00, 0x00, 0x88};
+  ClutterActor *text_group;
+  static gint width, height;
+  gint size;
+  gfloat stage_w, stage_h;
+  PangoFontDescription *pfd;
   PangoLayout *layout;
-  PangoFontDescription * pfd;
-  int size;
-  static int width, height;
+  PangoContext *context;
 
-  zero_board ();
+  gchar *nibbles = _("Nibbles");
+  /* Translators: This string will be included in the intro screen, so don't make sure it fits! */
+  gchar *description = _("A worm game for GNOME.");
 
-  gdk_draw_pixbuf (GDK_DRAWABLE (buffer_pixmap),
-		   drawing_area->style->
-		   fg_gc[GTK_WIDGET_STATE (drawing_area)], logo_pixmap, 0, 0,
-		   0, 0, BOARDWIDTH * properties->tilesize,
-		   BOARDHEIGHT * properties->tilesize, GDK_RGB_DITHER_NORMAL,
-		   0, 0);
+  logo = clutter_group_new ();
+  text_group = clutter_group_new ();
+
+  if (!logo_pixmap)
+    gnibbles_load_logo (properties->tilesize);
+
+  image = gtk_clutter_texture_new_from_pixbuf (logo_pixmap);
+
+  stage_w = board->width * properties->tilesize;
+  stage_h = board->height * properties->tilesize;
+
+  clutter_actor_set_size (CLUTTER_ACTOR (image), stage_w, stage_h);
+
+  clutter_actor_set_position (CLUTTER_ACTOR (image), 0, 0);
+  clutter_actor_show (image);
+
+  text = clutter_text_new ();
+  clutter_text_set_color (CLUTTER_TEXT (text), &actor_color);
 
   context = gdk_pango_context_get ();
-  layout = pango_layout_new (context);
+  layout = clutter_text_get_layout (CLUTTER_TEXT (text));
   pfd = pango_context_get_font_description (context);
   size = pango_font_description_get_size (pfd);
-  pango_font_description_set_size (pfd, 
-		(size * drawing_area->allocation.width) / 100);
+
+  pango_font_description_set_size (pfd, (size * stage_w) / 100);
   pango_font_description_set_family (pfd, "Sans");
-  pango_font_description_set_weight(pfd, PANGO_WEIGHT_BOLD); 
+  pango_font_description_set_weight(pfd, PANGO_WEIGHT_BOLD);
   pango_layout_set_font_description (layout, pfd);
-  pango_layout_set_text (layout, _("Nibbles"), -1);
-  pango_layout_get_pixel_size(layout, &width, &height);  
+  pango_layout_set_text (layout, nibbles, -1);
+  pango_layout_get_pixel_size (layout, &width, &height);
 
-  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->black_gc,  
-		   (drawing_area->allocation.width - width) * 0.5 + 3, 
-		   (drawing_area->allocation.height * 0.72) + 3, layout);
-  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->white_gc,  
-		   (drawing_area->allocation.width - width) * 0.5, 
-		   (drawing_area->allocation.height * 0.72), layout);
+  text_shadow = clutter_text_new ();
+  clutter_text_set_color (CLUTTER_TEXT (text_shadow), &shadow_color);
 
-  pango_font_description_set_size (pfd, 
-		(size * drawing_area->allocation.width) / 400);
+  layout = clutter_text_get_layout (CLUTTER_TEXT (text_shadow));
   pango_layout_set_font_description (layout, pfd);
-  /* Translators: This string will be included in the intro screen, so don't make sure it fits! */
-  pango_layout_set_text (layout, _("A worm game for GNOME."), -1);
-  pango_layout_get_pixel_size(layout, &width, &height);  
+  pango_layout_set_text (layout, nibbles, -1);
 
-  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->black_gc,
-		   (drawing_area->allocation.width - width) * 0.5 + 2, 
-                   (drawing_area->allocation.height * 0.94) + 2, layout);
-  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->white_gc,
-		   (drawing_area->allocation.width - width) * 0.5,
-                   (drawing_area->allocation.height * 0.94), layout);
+  clutter_actor_set_position (CLUTTER_ACTOR (text),
+                              (stage_w - width) * 0.5 ,
+                              stage_h * .72);
+  clutter_actor_set_position (CLUTTER_ACTOR (text_shadow),
+                              (stage_w - width) * 0.5 + 5,
+                              stage_h * .72 + 5);
 
+  desc = clutter_text_new ();
+  layout = clutter_text_get_layout (CLUTTER_TEXT (desc));
 
-  gdk_draw_drawable (GDK_DRAWABLE (drawing_area->window),
-		     drawing_area->style->
-		     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 
-		     0, 0, 0, 0, BOARDWIDTH * properties->tilesize,
-		     BOARDHEIGHT * properties->tilesize);
+  clutter_text_set_color (CLUTTER_TEXT (desc), &actor_color);
+  pango_font_description_set_size (pfd, (size * stage_w) / 400);
+  pango_layout_set_font_description (layout, pfd);
+  pango_layout_set_text (layout, description, -1);
+  pango_layout_get_pixel_size(layout, &width, &height);
 
+  desc_shadow = clutter_text_new ();
+  layout = clutter_text_get_layout (CLUTTER_TEXT (desc_shadow));
+  clutter_text_set_color (CLUTTER_TEXT (desc_shadow), &shadow_color);
 
+  pango_font_description_set_size (pfd, (size * stage_w) / 400);
+  pango_layout_set_font_description (layout, pfd);
+  pango_layout_set_text (layout, description, -1);
+
+  clutter_actor_set_position (CLUTTER_ACTOR (desc),
+                              (stage_w - width) * 0.5,
+                              stage_h* .93);
+  clutter_actor_set_position (CLUTTER_ACTOR (desc_shadow),
+                              (stage_w - width) * 0.5 + 3,
+                              stage_h * .93 + 3);
+
+  clutter_container_add (CLUTTER_CONTAINER (text_group),
+                         CLUTTER_ACTOR (text_shadow),
+                         CLUTTER_ACTOR (text),
+                         CLUTTER_ACTOR (desc_shadow),
+                         CLUTTER_ACTOR (desc),
+                         NULL);
+  clutter_container_add (CLUTTER_CONTAINER (logo),
+                         CLUTTER_ACTOR (image),
+                         CLUTTER_ACTOR (text_group),
+                         NULL);
+
+  clutter_actor_set_opacity (CLUTTER_ACTOR (text_group), 0);
+  clutter_actor_set_scale (CLUTTER_ACTOR (text_group), 0.0, 0.0);
+  clutter_actor_animate (text_group, CLUTTER_EASE_OUT_CIRC, 800,
+                          "opacity", 0xff,
+                          "scale-x", 1.0,
+                          "scale-y", 1.0,
+                          "fixed::scale-center-y", stage_w / 2,
+                          "fixed::scale-center-x", stage_h / 2,
+                          NULL);
+
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage),
+                               CLUTTER_ACTOR (logo));
+}
+
+static void
+on_hide_logo_completed (ClutterAnimation *animation, ClutterActor *actor)
+{
+  clutter_actor_hide (actor);
+  clutter_group_remove_all (CLUTTER_GROUP (actor));
+}
+
+static void
+hide_logo (void)
+{
+  g_signal_connect_after (
+    clutter_actor_animate (logo, CLUTTER_EASE_IN_QUAD, 150,
+                           "opacity", 0,
+                           NULL),
+    "completed", G_CALLBACK (on_hide_logo_completed), logo);
 }
 
 int
@@ -1034,11 +1066,12 @@ main (int argc, char **argv)
   setgid_io_init ();
 #endif
 
+  gtk_clutter_init (&argc, &argv);
   context = g_option_context_new (NULL);
 
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif 
+#endif
 
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
@@ -1062,26 +1095,16 @@ main (int argc, char **argv)
                                  GAMES_SCORES_STYLE_PLAIN_DESCENDING);
 
   games_conf_initialise ("Gnibbles");
-
   properties = gnibbles_properties_new ();
-
   setup_window ();
+  gnibbles_load_pixmap (properties->tilesize);
+  gnibbles_load_logo (properties->tilesize);
 
-  gnibbles_load_logo (window);
-  gnibbles_load_pixmap (window);
-
-  gtk_widget_show (window);
-
-  buffer_pixmap = gdk_pixmap_new (drawing_area->window,
-				  BOARDWIDTH * properties->tilesize,
-				  BOARDHEIGHT * properties->tilesize, -1);
 #ifdef GGZ_CLIENT
   network_init ();
   network_gui_update ();
 #endif
 
-  render_logo ();
-
   gtk_action_set_sensitive (pause_action, FALSE);
   gtk_action_set_sensitive (resume_action, FALSE);
   gtk_action_set_sensitive (end_game_action, FALSE);
@@ -1092,7 +1115,6 @@ main (int argc, char **argv)
   gtk_main ();
 
   gnibbles_properties_destroy (properties);
-
   games_conf_shutdown ();
 
   games_runtime_shutdown ();
