@@ -8,11 +8,11 @@
 typedef struct _GameObject GameObject;
 
 struct _GameObject {
-  gint        x;
-  gint        y;
-  gint        type;
-  gint        oldx;
-  gint        oldy;
+  gint x;
+  gint y;
+  gint type;
+  gint oldx;
+  gint oldy;
   GameObject *next;
   GameObject *prev;
 };
@@ -22,11 +22,13 @@ struct _GameObject {
 /**********************************************************************/
 /* Exported functions                                                 */
 /**********************************************************************/
-void init_game();
-void cleanup_game();
-void game_keypress(gint);
-void show_scores(guint);
-void start_new_game();
+void init_game (void);
+void quit_game (void);
+void game_keypress (gint);
+gint show_scores (gint, gboolean);
+void start_new_game (void);
+gboolean mouse_cb (GtkWidget * widget, GdkEventButton * e, gpointer data);
+gboolean move_cb (GtkWidget * widget, GdkEventMotion * e, gpointer data);
 /**********************************************************************/
 
 
@@ -38,9 +40,3 @@ extern gint game_state;
 
 
 #endif /* GAME_H */
-
-
-
-
-
-
