@@ -31,6 +31,7 @@
 #endif
 
 #include "games-debug.h"
+#include "games-glib-compat.h"
 #include "games-gtk-compat.h"
 #include "games-marshal.h"
 
@@ -50,6 +51,7 @@ struct _GamesConfPrivate {
   char *main_group;
 #endif
   guint need_init : 1;
+  guint dirty : 1;
 };
 
 enum
@@ -133,11 +135,7 @@ free_window_state (WindowState *state)
 
   g_free (state->group);
 
-#if GLIB_CHECK_VERSION (2, 10, 0)
   g_slice_free (WindowState, state);
-#else
-  g_free (state);
-#endif
 }
 
 static gboolean
@@ -163,15 +161,9 @@ window_configure_event_cb (GtkWidget *widget,
                       state->window);
 
     if (state->timeout_id == 0) {
-#if GLIB_CHECK_VERSION (2, 14, 0)
       state->timeout_id = g_timeout_add_seconds (WINDOW_STATE_TIMEOUT,
                                                  (GSourceFunc) window_state_timeout_cb,
                                                  state);
-#else
-      state->timeout_id = g_timeout_add (WINDOW_STATE_TIMEOUT * 1000,
-                                         (GSourceFunc) window_state_timeout_cb,
-                                         state);
-#endif
     }
   }
 
@@ -217,11 +209,16 @@ games_conf_get_accel_map_path (GamesConf *conf,
   GamesConfPrivate *priv = conf->priv;
   char *game_name, *conf_dir;
   char *conf_file = NULL;
+  const char *override;
 
   game_name = g_ascii_strdown (priv->game_name, -1);
 
 #ifdef HAVE_GNOME
-  conf_dir = g_build_filename (g_get_home_dir (), ".gnome2", "accels", NULL);
+  override = g_getenv ("GNOME22_USER_DIR");
+  if (override)
+    conf_dir = g_build_filename (override, "accels", NULL);
+  else
+    conf_dir = g_build_filename (g_get_home_dir (), ".gnome2", "accels", NULL);
 #else
   conf_dir = g_build_filename (g_get_user_config_dir (), "gnome-games", NULL);
 #endif
@@ -351,6 +348,18 @@ get_gconf_value_type_from_schema (const char *key_name)
 
 #endif /* HAVE_GNOME */
 
+#ifndef HAVE_GNOME
+
+static void
+mark_dirty_cb (GamesConf *conf)
+{
+  GamesConfPrivate *priv = conf->priv;
+
+  priv->dirty = TRUE;
+}
+
+#endif /* !HAVE_GNOME */
+
 /* Class implementation */
 
 static void
@@ -361,6 +370,11 @@ games_conf_init (GamesConf *conf)
   priv = conf->priv = GAMES_CONF_GET_PRIVATE (conf);
 
   priv->need_init = FALSE;
+  priv->dirty = FALSE;
+
+#ifndef HAVE_GNOME
+  g_signal_connect (conf, "value-changed", G_CALLBACK (mark_dirty_cb), NULL);
+#endif
 }
 
 static GObject *
@@ -456,44 +470,8 @@ games_conf_finalize (GObject *object)
   priv->gconf_client = NULL;
 
 #else /* !HAVE_GNOME */
-  char *game_name, *conf_file, *conf_dir, *data = NULL;
-  gsize len = 0;
-  GError *error = NULL;
 
-  game_name = g_ascii_strdown (priv->game_name, -1);
-  conf_file = g_build_filename (g_get_user_config_dir (), "gnome-games", game_name, NULL);
-
-  /* Ensure the directory exists */
-  conf_dir = g_build_filename (g_get_user_config_dir (), "gnome-games", NULL);
-  /* Mode 0700 per the XDG basedir spec */
-  if (g_mkdir_with_parents (conf_dir, 0700) < 0) {
-    int err = errno;
-
-    if (err != EEXIST) {
-      g_warning ("Failed to create config directory \"%s\": %s\n", conf_dir, g_strerror (err));
-      goto loser;
-    }
-  }
-
-  data = g_key_file_to_data (priv->key_file, &len, &error);
-  if (!data) {
-    g_warning ("Failed to save settings to \"%s\": %s",
-               conf_file, error->message);
-    g_error_free (error);
-    goto loser;
-  }
-
-  if (!g_file_set_contents (conf_file, data, len, &error)) {
-    g_warning ("Failed to save settings to \"%s\": %s",
-              conf_file, error->message);
-    g_error_free (error);
-  }
-
-loser:
-  g_free (data);
-  g_free (conf_file);
-  g_free (conf_dir);
-  g_free (game_name);
+  games_conf_save ();
 
   g_free (priv->main_group);
   g_key_file_free (priv->key_file);
@@ -618,6 +596,63 @@ games_conf_get_default (void)
   return instance;
 }
 
+/**
+ * games_conf_save:
+ *
+ * Ensures settings are written to disk.
+ */
+void
+games_conf_save (void)
+{
+#ifndef HAVE_GNOME
+  GamesConfPrivate *priv = instance->priv;
+  char *game_name, *conf_file, *conf_dir, *data = NULL;
+  gsize len = 0;
+  GError *error = NULL;
+
+  if (!priv->dirty)
+    return;
+
+  game_name = g_ascii_strdown (priv->game_name, -1);
+  conf_dir = g_build_filename (g_get_user_config_dir (), "gnome-games", NULL);
+  conf_file = g_build_filename (conf_dir, game_name, NULL);
+
+  /* Ensure the directory exists; mode 0700 per the XDG basedir spec. */
+  if (g_mkdir_with_parents (conf_dir, 0700) < 0) {
+    int err = errno;
+
+    if (err != EEXIST) {
+      g_warning ("Failed to create config directory \"%s\": %s\n", conf_dir, g_strerror (err));
+      goto loser;
+    }
+  }
+
+  data = g_key_file_to_data (priv->key_file, &len, &error);
+  if (!data) {
+    g_warning ("Failed to save settings to \"%s\": %s",
+               conf_file, error->message);
+    g_error_free (error);
+    goto loser;
+  }
+
+  if (!g_file_set_contents (conf_file, data, len, &error)) {
+    g_warning ("Failed to save settings to \"%s\": %s",
+              conf_file, error->message);
+    g_error_free (error);
+    goto loser;
+  }
+
+  /* Sucessfully saved */
+  priv->dirty = FALSE;
+
+loser:
+  g_free (data);
+  g_free (conf_file);
+  g_free (conf_dir);
+  g_free (game_name);
+#endif /* !HAVE_GNOME */
+}
+
 /**
  * games_conf_get_string:
  * @group: the group name, or %NULL to use the default group
@@ -1260,11 +1295,7 @@ games_conf_add_window (GtkWindow *window,
   g_return_if_fail (GTK_IS_WINDOW (window));
   g_return_if_fail (!GTK_WIDGET_REALIZED (window));
 
-#if GLIB_CHECK_VERSION (2, 10, 0)
   state = g_slice_new0 (WindowState);
-#else
-  state = g_new0 (WindowState, 1);
-#endif
 
   state->window = window;
   state->group = g_strdup (group);
