@@ -708,7 +708,7 @@ properties_callback (void)
 					     GTK_STOCK_CLOSE,
 					     GTK_RESPONSE_CLOSE, NULL);
   gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (pref_dialog))), 2);
   gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
   gtk_window_set_resizable (GTK_WINDOW (pref_dialog), FALSE);
   gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog),
@@ -786,7 +786,7 @@ properties_callback (void)
 
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox),
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (pref_dialog))),
 			       top_table, TRUE, TRUE, 0);
 
   g_object_unref (group);
